@@ -6,12 +6,11 @@ test_that("simplify_shapes", {
 
     poa_simpl <- simplify_shapes(poa, 1e-5)
 
-    expect(poa_simpl$shapes$shape_id |> unique() |> length(), 4)
+    expect_equal(poa_simpl$shapes$shape_id |> unique() |> length(), 4)
     expect_equal(dim(poa_simpl$shapes)[1], 867)
 
     poa_simpl <- simplify_shapes(poa, 1e-3)
 
-    expect(poa_simpl$shapes$shape_id |> unique() |> length(), 4)
+    expect_equal(poa_simpl$shapes$shape_id |> unique() |> length(), 4)
     expect_equal(dim(poa_simpl$shapes)[1], 115)
 })
-
